@@ -46,8 +46,8 @@ def factorizing_could_speedup(module: torch.nn.Module, latent_size: Union[int, f
     and more per-op overhead.
 
     Args:
-        module (:class:`torch.nn.Module`): a :class:`~torch.nn.Conv2d`, :class:`~torch.nn.Linear`,
-            :class:`~FactorizedConv2d`, or :class:`~FactorizedLinear`.
+        module (torch.nn.Module): A :class:`torch.nn.Conv2d`, :class:`torch.nn.Linear`,
+            :class:`.FactorizedConv2d`, or :class:`.FactorizedLinear`.
         latent_size (int | float): number of channels (for convolution) or
             features (for linear) in the latent representation. Can be
             specified as either an integer > 1 or as float within ``[0, 1)``.
@@ -56,8 +56,7 @@ def factorizing_could_speedup(module: torch.nn.Module, latent_size: Union[int, f
             ``min(in_channels, out_channels)`` for a convolution.
 
     Returns:
-        could_speedup:
-            A ``bool`` indicating whether the provided amount of factorization
+        bool: A ``bool`` indicating whether the provided amount of factorization
             could accelerate the provided module. If ``module`` is not one of
             the allowed types, always returns ``False``, since there is no
             supported way to factorize that module.
@@ -114,8 +113,8 @@ class _FactorizedModule(nn.Module, abc.ABC):
         self.kernel_size = kernel_size
 
     def _check_child_modules_present(self):
-        assert hasattr(self, 'module0'), "module0 must be set during child class __init__!"
-        assert hasattr(self, 'module1'), "module1 must be set during child class __init__!"
+        assert hasattr(self, 'module0'), 'module0 must be set during child class __init__!'
+        assert hasattr(self, 'module1'), 'module1 must be set during child class __init__!'
         assert isinstance(self.module0, torch.nn.Module)
         assert isinstance(self.module1, torch.nn.Module)
 
@@ -139,17 +138,17 @@ class _FactorizedModule(nn.Module, abc.ABC):
         latent rank.
 
         Args:
-            input (:class:`torch.Tensor`): Tensor that can be passed to the model's `forward()` method.
-            rank (int): dimensionality of the latent representation; this is the
+            input (torch.Tensor): Tensor that can be passed to the model's `forward()` method.
+            rank (int): Dimensionality of the latent representation; this is the
                 size of the vector space when factorizing linear modules and
                 the number of channels for convolutional modules.
 
         Raises:
             ValueError:
-                If ``rank`` is larger than the current latent rank
+                If ``rank`` is larger than the current latent rank.
         """
         if rank > self.latent_size:
-            raise ValueError(f"Requested rank {rank} exceeds current rank {self.latent_size}")
+            raise ValueError(f'Requested rank {rank} exceeds current rank {self.latent_size}')
         if rank == self.latent_size:
             return
         soln = self.solution_for_rank(input, rank)
@@ -185,7 +184,7 @@ class _FactorizedModule(nn.Module, abc.ABC):
         many possible solutions for a given module before choosing one.
 
         Args:
-            input (:class:`torch.Tensor`): An input to the module used to optimize the solution's
+            input (torch.Tensor): An input to the module used to optimize the solution's
                 weights. The optimization seeks to preserve the module's
                 input-output mapping as much as possible, subject to the
                 specified rank constraint.
@@ -207,8 +206,8 @@ class _FactorizedModule(nn.Module, abc.ABC):
         using the solution is worthwhile.
 
         Args:
-            solution (:class:`LowRankSolution`): an object encapsulating the new 
-                parameters to be used and their associated mean squared error on 
+            solution (LowRankSolution): An object encapsulating the new
+                parameters to be used and their associated mean squared error on
                 the input for which they were optimized. Can be obtained using
                 :meth:`~solution_for_rank`.
         """
@@ -230,11 +229,11 @@ class FactorizedConv2d(_FactorizedModule):
     one always has a kernel size of :math:`1 \\times 1`. For large kernel sizes, the
     lower-dimensional space can be nearly as large as
     ``min(in_channels, out_channels)`` and still yield a reduction in
-    multiply-add operations. For kernels sizes of :math:`1 \\times 1`, the breakeven
-    point is a 2x reduction in channel count, similar to
-    :class:`~FactorizedLinear`.
+    multiply-add operations. For kernels sizes of :math:`1 \\times 1`,
+    the break-even point is a 2x reduction in channel count, similar to
+    :class:`.FactorizedLinear`.
 
-    See :func:`~composer.factorize.factorize_conv2d` for more details.
+    See :func:`.factorize_conv2d` for more details.
 
     Args:
         in_channels (int): number of channels in the input image.
@@ -273,7 +272,7 @@ class FactorizedConv2d(_FactorizedModule):
                          latent_size=latent_channels,
                          kernel_size=kernel_size)
         if kwargs.get('groups', 1) > 1:
-            raise NotImplementedError("Factorizing grouped convolutions is not supported.")
+            raise NotImplementedError('Factorizing grouped convolutions is not supported.')
         self.kwargs = kwargs
         # conv2d factorization code requires most Conv2d arguments, but
         # not boolean 'bias'
@@ -283,7 +282,7 @@ class FactorizedConv2d(_FactorizedModule):
     def _create_child_modules(self) -> Tuple[torch.nn.Module, torch.nn.Module]:
         if not self.should_factorize(self.latent_channels):
             raise ValueError(
-                f"latent_channels {self.latent_size} is not small enough to merit factorization! Must be <= {self._max_rank_with_speedup()}"
+                f'latent_channels {self.latent_size} is not small enough to merit factorization! Must be <= {self._max_rank_with_speedup()}'
             )
 
         # this one produces identical output as a regular Conv2d would,
@@ -310,8 +309,8 @@ class FactorizedConv2d(_FactorizedModule):
 
     @property
     def latent_channels(self) -> int:
-        """The number of of output channels for the first convolution, which is also the number of input channels for
-        the second convolution."""
+        """The number of of output channels for the first convolution,
+        which is also the number of input channels for the second convolution."""
         return self.latent_size
 
     def solution_for_rank(self, input: torch.Tensor, rank: int) -> LowRankSolution:
@@ -380,16 +379,16 @@ class FactorizedLinear(_FactorizedModule):
     better, it may take a reduction of more than 2x to get a speedup
     in practice.
 
-    See :func:`~composer.factorize.factorize_matrix` for more details.
+    See :func:`.factorize_matrix` for more details.
 
     Args:
-        in_features (int): size of each input sample
+        in_features (int): Size of each input sample
         out_features (int): size of each output sample
         bias (bool, optional): If set to False, the layer will not learn an additive bias.
             Default: ``True``.
-        latent_features (int | float, optional): size of the latent space.
+        latent_features (int | float, optional): Size of the latent space.
             Can be specified as either an integer > 1 or as a float within
-            [0, 0.5). In the latter case, the value is interpreted as a fraction
+            ``[0, 0.5)``. In the latter case, the value is interpreted as a fraction
             of ``min(in_features, out_features)``, and is converted to the
             equivalent integer value, with a minimum of 1. Default: ``.25``.
 
@@ -416,7 +415,7 @@ class FactorizedLinear(_FactorizedModule):
     def _create_child_modules(self) -> Tuple[torch.nn.Module, torch.nn.Module]:
         if not self.should_factorize(self.latent_size):
             raise ValueError(
-                f"latent_features {self.latent_size} is not small enough to merit factorization! Must be <= {self._max_rank_with_speedup()}"
+                f'latent_features {self.latent_size} is not small enough to merit factorization! Must be <= {self._max_rank_with_speedup()}'
             )
 
         module0 = nn.Linear(in_features=self.in_features, out_features=self.latent_size, bias=False)
@@ -436,7 +435,7 @@ class FactorizedLinear(_FactorizedModule):
 
     @property
     def latent_features(self) -> int:
-        """The dimensionality of the space into which the input is 
+        """The dimensionality of the space into which the input is
         projected by the first matrix in the factorization."""
         return self.latent_size
 
@@ -462,11 +461,11 @@ class FactorizedLinear(_FactorizedModule):
         """Returns the largest latent feature count that reduces the number of multiply-adds.
 
         Args:
-            in_features (int): size of each input sample
-            out_features (int): size of each output sample
+            in_features (int): Size of each input sample.
+            out_features (int): Size of each output sample.
 
         Returns:
-            latent_features: the largest allowable number of latent features
+            int: The largest allowable number of latent features.
         """
         return _max_rank_with_possible_speedup(in_features, out_features)
 
