@@ -12,4 +12,4 @@ from composer.algorithms.squeeze_excite.squeeze_excite import SqueezeExcite2d as
 from composer.algorithms.squeeze_excite.squeeze_excite import SqueezeExciteConv2d as SqueezeExciteConv2d
 from composer.algorithms.squeeze_excite.squeeze_excite import apply_squeeze_excite as apply_squeeze_excite
 
-__all__ = ["SqueezeExcite", "SqueezeExcite2d", "SqueezeExciteConv2d", "apply_squeeze_excite"]
+__all__ = ['SqueezeExcite', 'SqueezeExcite2d', 'SqueezeExciteConv2d', 'apply_squeeze_excite']
