@@ -108,7 +108,7 @@ class Event(StringEnum):
             event allows the checkpoint saver to use the results from any batch-wise evaluation to determine whether
             a checkpoint should be saved.
         EPOCH_END: End of an epoch.
-        EPOCH_CHECKPOINT: After :attr:`.Event.EPOCH_END` and any epoch-wise evaluation. Saving checkpoints at this event allows
+        EPOCH_CHECKPOINT: After :attr:`.Event.EPOCH_END` and any epoch-wise evaluation. Saving checkpoints at this
             event allows the checkpoint saver to use the results from any epoch-wise evaluation to determine whether
             a checkpointshould be saved.
         FIT_END: Invoked at the end of each call to :meth:`.Trainer.fit`. This event exists primarily for logging information
