@@ -5,6 +5,7 @@
 
 from __future__ import annotations
 
+import os
 import sys
 from typing import Any, Callable, Dict, List, Optional, TextIO, Union
 
@@ -31,22 +32,28 @@ class _ProgressBar:
         file: TextIO,
         metrics: Dict[str, Any],
         keys_to_log: List[str],
-        unit: TimeUnit = TimeUnit.EPOCH,
-        epoch_style: bool = False,
+        timestamp_key: str,
+        unit: str = 'it',
     ) -> None:
         self.keys_to_log = keys_to_log
         self.metrics = metrics
         self.position = position
-        self.unit = unit
-        self.epoch_style = epoch_style
+        self.timestamp_key = timestamp_key
+        self.file = file
+        is_atty = os.isatty(self.file.fileno())
         self.pbar = tqdm.auto.tqdm(
             total=total,
             position=position,
             bar_format=bar_format,
             file=file,
-            dynamic_ncols=True,
+            ncols=None if is_atty else 120,
+            dynamic_ncols=is_atty,
+            # We set `leave=False` so TQDM does not jump around, but we emulate `leave=True` behavior when closing
+            # by printing a dummy newline and refreshing to force tqdm to print to a stale line
+            # But on k8s, we need `leave=True`, as it would otherwise overwrite the pbar in place
+            leave=not is_atty,
             postfix=metrics,
-            unit=unit.value,
+            unit=unit,
         )
 
     def log_data(self, data: Dict[str, Any]):
@@ -58,15 +65,19 @@ class _ProgressBar:
         self.pbar.update(n=n)
 
     def update_to_timestamp(self, timestamp: Timestamp):
-        if self.epoch_style:
-            n = int(timestamp.batch_in_epoch)
-        else:
-            n = int(timestamp.get(self.unit))
-
+        n = int(getattr(timestamp, self.timestamp_key))
         n = n - self.pbar.n
         self.pbar.update(int(n))
 
     def close(self):
+        if self.position != 0:
+            # Force a (potentially hidden) progress bar to re-render itself
+            # Don't render the dummy pbar (at position 0), since that will clear a real pbar (at position 1)
+            self.pbar.refresh()
+        # Create a newline that will not be erased by leave=False. This allows for the finished pbar to be cached in the terminal
+        # This emulates `leave=True` without progress bar jumping
+        print('', file=self.file, flush=True)
+
         self.pbar.close()
 
     def state_dict(self) -> Dict[str, Any]:
@@ -79,8 +90,7 @@ class _ProgressBar:
             'metrics': self.metrics,
             'keys_to_log': self.keys_to_log,
             'n': pbar_state['n'],
-            'unit': self.unit,
-            'epoch_style': self.epoch_style
+            'timestamp_key': self.timestamp_key,
         }
 
 
@@ -130,9 +140,12 @@ class ProgressBarLogger(LoggerDestination):
     ) -> None:
 
         self._show_pbar = progress_bar
+        # The dummy pbar is to fix issues when streaming progress bars over k8s, where the progress bar in position 0
+        # doesn't update until it is finished.
+        # Need to have a dummy progress bar in position 0, so the "real" progress bars in position 1 doesn't jump around
+        self.dummy_pbar: Optional[_ProgressBar] = None
         self.train_pbar: Optional[_ProgressBar] = None
         self.eval_pbar: Optional[_ProgressBar] = None
-        self.is_train: Optional[bool] = None
 
         if isinstance(console_log_level, str):
             console_log_level = LogLevel(console_log_level)
@@ -161,30 +174,16 @@ class ProgressBarLogger(LoggerDestination):
 
         self.stream = stream
 
-    @property
-    def _current_pbar(self) -> Optional[_ProgressBar]:
-        if self.is_train is None:
-            return None
-        return self.train_pbar if self.is_train else self.eval_pbar
-
-    @_current_pbar.setter
-    def _current_pbar(self, pbar: Optional[_ProgressBar]):
-        assert self.is_train is not None, 'Cannot set pbar if self.is_train is not set.'
-
-        if self.is_train:
-            self.train_pbar = pbar
-        else:
-            self.eval_pbar = pbar
-
     @property
     def show_pbar(self) -> bool:
         return self._show_pbar and dist.get_local_rank() == 0
 
     def log_data(self, state: State, log_level: LogLevel, data: Dict[str, Any]) -> None:
         # log to progress bar
-        if self._current_pbar:
+        current_pbar = self.eval_pbar if self.eval_pbar is not None else self.train_pbar
+        if current_pbar:
             # Logging outside an epoch
-            self._current_pbar.log_data(data)
+            current_pbar.log_data(data)
 
         # log to console
         if self.should_log(state, log_level):
@@ -210,81 +209,91 @@ class ProgressBarLogger(LoggerDestination):
 
     def log_to_console(self, log_str: str):
         """Logs to the console, avoiding interleaving with a progress bar."""
-        if self._current_pbar:
+        current_pbar = self.eval_pbar if self.eval_pbar is not None else self.train_pbar
+        if current_pbar:
             # use tqdm.write to avoid interleaving
-            self._current_pbar.pbar.write(log_str)
+            current_pbar.pbar.write(log_str)
         else:
             # write directly to self.stream; no active progress bar
             print(log_str, file=self.stream, flush=True)
 
-    def _build_pbar(self, state: State, is_train: bool, epoch_style: bool = False) -> _ProgressBar:
-        """Builds a pbar that tracks in the units of max_duration.
+    def _build_pbar(self, state: State, is_train: bool) -> _ProgressBar:
+        """Builds a pbar.
 
-        Example:
-            Samples     train  73% ||███████████████        | 293873/400000
-
-        If epoch_style = True, then the pbar total will be the
-        numbers of batches in the epoch, regardless of the max_duration units.
-        This is often used to emit a pbar for each epoch, e.g.
-            Epoch     0 train 100%|█████████████████████████| 29/29
-            Epoch     1 train 100%|█████████████████████████| 29/29
+        *   If ``state.max_duration.unit`` is :attr:`.TimeUnit.EPOCH`, then a new progress bar will be created for each epoch.
+            Mid-epoch evaluation progress bars will be labeled with the batch and epoch number.
+        *   Otherwise, one progress bar will be used for all of training. Evaluation progress bars will be labeled
+            with the time (in units of ``max_duration.unit``) at which evaluation runs.
         """
-        position = 0 if is_train else 1
-        split = 'train' if is_train else 'val'
+        # Always using position=1 to avoid jumping progress bars
+        position = 1
+        desc = f'{state.dataloader_label:15}'
+        max_duration_unit = None if state.max_duration is None else state.max_duration.unit
 
-        assert self.is_train is not None
-        if epoch_style:
+        if max_duration_unit == TimeUnit.EPOCH or max_duration_unit is None:
             total = int(state.dataloader_len) if state.dataloader_len is not None else None
-
-            # handle when # batches is less than an epoch
-            if total is not None and state.max_duration is not None \
-                and state.max_duration.unit == TimeUnit.BATCH:
-                total = min(total, state.max_duration.value)
+            timestamp_key = 'batch_in_epoch'
 
             unit = TimeUnit.BATCH
             n = state.timestamp.epoch.value
-            if not is_train:
-                # eval results refer to model from previous epoch (n-1)
-                n = max(0, n - 1)
-            desc = f'Epoch {n:5d} {split:5s}'
-        else:
-            assert state.max_duration is not None, 'max_duration should be set'
+            if self.train_pbar is None and not is_train:
+                # epochwise eval results refer to model from previous epoch (n-1)
+                n -= 1
+            if self.train_pbar is None:
+                desc += f'Epoch {n:3}'
+            else:
+                # For evaluation mid-epoch, show the total batch count
+                desc += f'Batch {int(state.timestamp.batch):3}'
+            desc += ': '
 
-            total = state.max_duration.value
-            unit = state.max_duration.unit
-            desc = f'{unit.name.capitalize():<11} {split:5s}'
+        else:
+            if is_train:
+                assert state.max_duration is not None, 'max_duration should be set if training'
+                unit = max_duration_unit
+                total = state.max_duration.value
+                # pad for the expected length of an eval pbar -- which is 14 characters (see the else logic below)
+                desc = desc.ljust(len(desc) + 14)
+            else:
+                unit = TimeUnit.BATCH
+                total = int(state.dataloader_len) if state.dataloader_len is not None else None
+                value = int(state.timestamp.get(max_duration_unit))
+                # Longest unit name is sample (6 characters)
+                desc += f'{max_duration_unit.name.capitalize():6} {value:5}: '
+
+            timestamp_key = unit.name.lower()
 
         return _ProgressBar(
             file=self.stream,
             total=total,
             position=position,
-            keys_to_log=_IS_TRAIN_TO_KEYS_TO_LOG[self.is_train],
-            bar_format=f'{desc} {{l_bar}}{{bar:25}}{{r_bar}}{{bar:-1b}}',
-            unit=unit,
+            keys_to_log=_IS_TRAIN_TO_KEYS_TO_LOG[is_train],
+            bar_format=desc + ' {l_bar}{bar:25}{r_bar}{bar:-1b}',
+            unit=unit.value.lower(),
             metrics={},
-            epoch_style=epoch_style,
+            timestamp_key=timestamp_key,
         )
 
-    def _close(self):
-        if self._current_pbar:
-            self._current_pbar.close()
-            self._current_pbar = None
-            self.is_train = None
+    def init(self, state: State, logger: Logger) -> None:
+        del state, logger  # unused
+        self.dummy_pbar = _ProgressBar(
+            file=self.stream,
+            position=0,
+            total=1,
+            metrics={},
+            keys_to_log=[],
+            bar_format='{bar:-1b}',
+            timestamp_key='',
+        )
 
     def epoch_start(self, state: State, logger: Logger) -> None:
-        self.is_train = True
-        assert state.max_duration is not None, 'max_duration should be set'
-        epoch_style = state.max_duration.unit == TimeUnit.EPOCH
         if self.show_pbar and not self.train_pbar:
-            self.train_pbar = self._build_pbar(state=state, is_train=True, epoch_style=epoch_style)
+            self.train_pbar = self._build_pbar(state=state, is_train=True)
 
     def eval_start(self, state: State, logger: Logger) -> None:
-        self.is_train = False
         if self.show_pbar:
-            self.eval_pbar = self._build_pbar(state, is_train=False, epoch_style=True)
+            self.eval_pbar = self._build_pbar(state, is_train=False)
 
     def batch_end(self, state: State, logger: Logger) -> None:
-        self.is_train = True
         if self.train_pbar:
             self.train_pbar.update_to_timestamp(state.timestamp)
 
@@ -293,28 +302,66 @@ class ProgressBarLogger(LoggerDestination):
             self.eval_pbar.update_to_timestamp(state.eval_timestamp)
 
     def epoch_end(self, state: State, logger: Logger) -> None:
-        # only close the progress bar if its epoch_style
-        if self.train_pbar and self.train_pbar.epoch_style:
-            self._close()
+        # Only close progress bars at epoch end if the duration is in epochs, since
+        # a new pbar will be created for each epoch
+        # If the duration is in other units, then one progress bar will be used for all of training.
+        assert state.max_duration is not None, 'max_duration should be set'
+        if self.train_pbar and state.max_duration.unit == TimeUnit.EPOCH:
+            self.train_pbar.close()
+            self.train_pbar = None
+
+    def close(self, state: State, logger: Logger) -> None:
+        del state, logger  # unused
+        # Close any open progress bars
+        if self.eval_pbar:
+            self.eval_pbar.close()
+            self.eval_pbar = None
+        if self.train_pbar:
+            self.train_pbar.close()
+            self.train_pbar = None
+        if self.dummy_pbar:
+            self.dummy_pbar.close()
+            self.dummy_pbar = None
 
     def eval_end(self, state: State, logger: Logger) -> None:
-        self._close()
+        if self.eval_pbar:
+            self.eval_pbar.close()
+            self.eval_pbar = None
 
     def state_dict(self) -> Dict[str, Any]:
         return {
             'train_pbar': self.train_pbar.state_dict() if self.train_pbar else None,
             'eval_pbar': self.eval_pbar.state_dict() if self.eval_pbar else None,
-            'is_train': self.is_train,
         }
 
     def load_state_dict(self, state: Dict[str, Any]) -> None:
         if state['train_pbar']:
             n = state['train_pbar'].pop('n')
-            self.train_pbar = _ProgressBar(file=self.stream, **state['train_pbar'])
+            train_pbar = self._ensure_backwards_compatibility(state['train_pbar'])
+            self.train_pbar = _ProgressBar(file=self.stream, **train_pbar)
             self.train_pbar.update(n=n)
         if state['eval_pbar']:
             n = state['train_pbar'].pop('n')
-            self.eval_pbar = _ProgressBar(file=self.stream, **state['eval_pbar'])
+            eval_pbar = self._ensure_backwards_compatibility(state['eval_pbar'])
+            self.eval_pbar = _ProgressBar(file=self.stream, **eval_pbar)
             self.eval_pbar.update(n=n)
 
-        self.is_train = state['is_train']
+    def _ensure_backwards_compatibility(self, state: Dict[str, Any]) -> Dict[str, Any]:
+        # ensure backwards compatible with mosaicml<=v0.8.0 checkpoints
+
+        state.pop('epoch_style', None)
+
+        # old checkpoints do not have timestamp_key
+        if 'timestamp_key' not in state:
+            if 'unit' not in state:
+                raise ValueError('Either unit or timestamp_key must be in pbar state of checkpoint.')
+            unit = state['unit']
+            assert isinstance(unit, TimeUnit)
+
+            state['timestamp_key'] = unit.name.lower()
+
+        # new format expects unit as str, not TimeUnit
+        if 'unit' in state and isinstance(state['unit'], TimeUnit):
+            state['unit'] = state['unit'].value.lower()
+
+        return state
