@@ -11,7 +11,7 @@ See the :doc:`Model Card </model_cards/GPT2>` for more details.
 from composer.models.gpt2.gpt2_hparams import GPT2Hparams as GPT2Hparams
 from composer.models.gpt2.model import GPT2Model as GPT2Model
 
-__all__ = ["GPT2Model", "GPT2Hparams"]
+__all__ = ['GPT2Model', 'GPT2Hparams']
 
 _metadata = {
     'gpt2': {
