@@ -10,7 +10,7 @@ import yahp as hp
 from composer.models.model_hparams import ModelHparams
 from composer.models.resnet.model import ComposerResNet
 
-__all__ = ["ResNetHparams"]
+__all__ = ['ResNetHparams']
 
 
 @dataclass
@@ -32,24 +32,25 @@ class ResNetHparams(ModelHparams):
     model_name: str = hp.optional(
         f"ResNet architecture to instantiate, must be one of {ComposerResNet.valid_model_names}. (default: '')",
         default='')
-    num_classes: int = hp.optional("Number of classes for the classification taks. (default: ``None``)", default=None)
-    pretrained: bool = hp.optional("If true, use ImageNet pretrained weights. (default: ``False``)", default=False)
+    pretrained: bool = hp.optional('If true, use ImageNet pretrained weights. (default: ``False``)', default=False)
     groups: int = hp.optional(
-        "Number of filter groups for the 3x3 convolution layer in bottleneck block. (default: ``1``)", default=1)
+        'Number of filter groups for the 3x3 convolution layer in bottleneck block. (default: ``1``)', default=1)
     width_per_group: int = hp.optional(
-        "Initial width for each convolution group. Width doubles after each stage. (default: ``64``)", default=64)
+        'Initial width for each convolution group. Width doubles after each stage. (default: ``64``)', default=64)
     loss_name: str = hp.optional(
         "Name of loss function. E.g. 'soft_cross_entropy' or 'binary_cross_entropy_with_logits'. (default: ``soft_cross_entropy``)",
-        default="soft_cross_entropy")
+        default='soft_cross_entropy')
 
     def validate(self):
         if self.model_name not in ComposerResNet.valid_model_names:
-            raise ValueError(f"model_name must be one of {ComposerResNet.valid_model_names}, but got {self.model_name}")
+            raise ValueError(f'model_name must be one of {ComposerResNet.valid_model_names}, but got {self.model_name}')
 
         if self.num_classes is None:
-            raise ValueError("num_classes must be specified")
+            raise ValueError('num_classes must be specified')
 
     def initialize_object(self):
+        if self.num_classes is None:
+            raise ValueError('num_classes must be specified')
         return ComposerResNet(model_name=self.model_name,
                               num_classes=self.num_classes,
                               pretrained=self.pretrained,
