@@ -7,4 +7,4 @@ used to create :class:`.ComposerClassifier`."""
 from composer.models.timm.model import Timm as Timm
 from composer.models.timm.timm_hparams import TimmHparams as TimmHparams
 
-__all__ = ["Timm", "TimmHparams"]
+__all__ = ['Timm', 'TimmHparams']
